#
# spec file for package fscrypt
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           fscrypt
Version:        0.3.4
Release:        3.7
Summary:        Go tool for managing Linux filesystem encryption
License:        Apache-2.0
Group:          System/Base
URL:            https://github.com/google/fscrypt
Source:         https://github.com/google/fscrypt/archive/refs/tags/v%{version}.tar.gz#/%{name}-%{version}.tar.gz
Source1:        vendor.tar.xz
Source2:        %name.pam
Source9:        baselibs.conf
BuildRequires:  golang-packaging
BuildRequires:  m4
BuildRequires:  pam-devel
BuildRequires:  pkgconfig
BuildRequires:  golang(API) >= 1.16
BuildRequires:  pkgconfig(bash-completion)
Requires:       pam-fscrypt = %{version}

%description
fscrypt is a high-level tool for the management of Linux filesystem encryption.
This tool manages metadata, key generation, key wrapping, PAM integration, and
provides a uniform interface for creating and modifying encrypted directories.

%package -n pam-fscrypt
#
Summary:        Go tool for managing Linux filesystem encryption (the pam module)
Group:          System/Base
Requires(pre):  fscrypt = %{version}

%description -n pam-fscrypt
fscrypt is a high-level tool for the management of Linux filesystem encryption.
This tool manages metadata, key generation, key wrapping, PAM integration, and
provides a uniform interface for creating and modifying encrypted directories.

This package holds the pam module for fscrypt.

%prep
%autosetup -p1 -a 1

%build
%global make_args GO_FLAGS="-mod=vendor -buildmode=pie" PAM_MODULE_DIR="%{_pam_moduledir}" PREFIX="%{_prefix}"
%make_build %{make_args}

%install
%make_install %{make_args}
# not needed on SUSE
rm -rvf %{buildroot}%{_datadir}/pam-configs
install -D -m 644 %{SOURCE2} %{buildroot}%{_pam_vendordir}/%{name}

%files
%license LICENSE
%doc README.md
%{_bindir}/fscrypt
%{_datadir}/bash-completion/completions/fscrypt

%files -n pam-fscrypt
%license LICENSE
%{_pam_moduledir}/pam_fscrypt.so
%{_pam_vendordir}/%{name}

%changelog
* Wed Mar  8 2023 Dirk Müller <dmueller@suse.com>
- move to pam_vendordir
- add baselibs
* Wed Feb 15 2023 Dirk Müller <dmueller@suse.com>
- add fscrypt pam configuration
- drop pam-specs from main package
* Tue Jan 31 2023 Marcus Rueckert <mrueckert@suse.de>
- update to 0.3.4:
  - fscrypt now requires Go 1.16 or later to build.
  - pam_fscrypt now supports the option unlock_only to disable
    locking of directories on logout.
  - Fixed a bug where the number of CPUs used in the passphrase
    hash would be calculated incorrectly on systems with more than
    255 CPUs.
  - Added support for AES-256-HCTR2 filenames encryption.
  - Directories are now synced immediately after an encryption
    policy is applied, reducing the chance of an inconsistency
    after a sudden crash.
  - Added Lustre to the list of allowed filesystems.
  - Added a NEWS.md file that contains the release notes, and
    backfilled it from the GitHub release notes.
* Tue Mar  8 2022 Dirk Müller <dmueller@suse.com>
- use pam_moduledir
* Thu Feb 24 2022 Dirk Müller <dmueller@suse.com>
- update to 0.3.3:
  * Correctly handle malicious mountpoint paths in the fscrypt bash completion
    script (CVE-2022-25328, command injection).
  * Validate the size, type, and owner (for login protectors) of policy and
    protector files (CVE-2022-25327, denial of service).
  * Make the fscrypt metadata directories non-world-writable by default
    (CVE-2022-25326, denial of service).
  * When running as a non-root user, ignore policy and protector files that
    aren't owned by the user or by root.
  * Also require that the metadata directories themselves and the mountpoint
    root directory be owned by the user or by root.
  * Make policy and protector files mode 0600 rather than 0644.
  * Make all relevant files owned by the user when root encrypts a directory
    with a user's login protector, not just the the login protector itself.
  * Make pam_fscrypt ignore system users completely.
- drop 346.patch: upstream
* Wed Feb 23 2022 Dirk Müller <dmueller@suse.com>
- refresh 346.patch with final merged state
* Tue Feb 22 2022 Dirk Müller <dmueller@suse.com>
- add 346.patch (bsc#1195623)
* Thu Feb 10 2022 Dirk Müller <dmueller@suse.com>
- update to 0.3.2:
  * Made linked protectors (e.g., login protectors used on a non-root filesystem)
    more reliable when a filesystem UUID changes.
  * Made login protectors be owned by the user when they are created as root, so
    that the user has permission to update them later.
  * Made fscrypt work when the root directory is a btrfs filesystem.
  * Made pam_fscrypt start warning when a user's login protector is getting
    de-synced due to their password being changed by root.
  * Support reading the key for raw key protectors from standard input.
  * Made fscrypt metadata remove-protector-from-policy work even if the protector
    is no longer accessible.
  * Made fscrypt stop trying to access irrelevant filesystems.
  * Improved the documentation.
* Fri Feb  4 2022 Dirk Müller <dmueller@suse.com>
- spec-cleaner run
* Wed Oct 20 2021 Marcus Rueckert <mrueckert@suse.de>
- Update to 0.3.1
  https://github.com/google/fscrypt/releases/tag/v0.3.1
* Thu Apr  1 2021 Marcus Rueckert <mrueckert@suse.de>
- Update to 0.3.0
  https://github.com/google/fscrypt/releases/tag/v0.3.0
* Mon Mar 29 2021 Marcus Rueckert <mrueckert@suse.de>
- Update to 0.2.9
  https://github.com/google/fscrypt/releases/tag/v0.2.9
  https://github.com/google/fscrypt/releases/tag/v0.2.8
* Tue Mar 24 2020 Marcus Rueckert <mrueckert@suse.de>
- initial package
